""" Test class for medium module """
import logging

from django.test import TransactionTestCase

from articles.models import MediumType, Medium
from articles.serializers import MediumTypeSerializer, MediumSerializer

logger = logging.getLogger(__name__)


class MediumTypeTest(TransactionTestCase):
    """ database test medium_type """
    reset_sequences = True

    def setUp(self):
        logger.info("started MediumTypeTest.setup")
        MediumType.objects.create(name='local', description='Lokale Zeitung')

    def test_db_call(self):
        """ Tests get medium_type db call """
        logger.info("started MediumTypeTest.test_db_call")
        local_print = MediumType.objects.get(name='local')
        self.assertEqual(local_print.description, 'Lokale Zeitung')
        self.assertEqual(local_print.id, 1)

    def test_serializer(self):
        """ Tests get medium_type serializer"""
        logger.info("started MediumTypeTest.test_serializer")
        MediumTypeSerializer().create({'name': 'regional', 'description': 'Regionale Zeitung'})
        self.assertEqual(MediumType.objects.count(), 2)


class MediumTest(TransactionTestCase):
    """ database test medium """
    reset_sequences = True

    def setUp(self):
        logger.info("started MediumTest.setup")
        MediumType.objects.create(name='new local', description='Lokale Zeitung')
        Medium.objects.create(name='Meine Zeitung', medium_type_id=1)

    def test_db_call(self):
        """ Tests get media """
        logger.info("started MediumTest.test_db_call")
        my_print = Medium.objects.get(name='Meine Zeitung')
        self.assertEqual(my_print.name, 'Meine Zeitung')
        self.assertEqual(my_print.medium_type.name, 'new local')
        self.assertEqual(my_print.medium_type.id, 1)

    def test_serializer(self):
        """ Tests get Medium serializer"""
        logger.info("started MediumTest.test_serializer")
        MediumSerializer().create({'medium_type': 'new local', 'name': 'Neue Zeitung'})
        self.assertEqual(MediumType.objects.count(), 1)
        self.assertEqual(Medium.objects.count(), 2)
